@@ -33,6 +33,9 @@ CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <netdb.h>
+#include <jpeglib.h>
+
+#include "transupp.h"
 
 Display *disp = NULL;
 Visual *vis = NULL;
@@ -254,16 +257,12 @@ feh_load_image(Imlib_Image * im, feh_file * file)
 char *
 feh_http_load_image(char *url)
 {
-   char *tmp;
    char *tmpname;
    char *tmpname_timestamper = NULL;
    char *basename;
-   char cppid[10];
-   static long int i = 1;
    char *newurl = NULL;
    char randnum[20];
    int rnum;
-   pid_t ppid;
    char *path = NULL;
 
    D_ENTER(4);
@@ -287,7 +286,7 @@ feh_http_load_image(char *url)
       pid_t ppid;
 
       ppid = getpid();
-      snprintf(cppid, sizeof(cppid), "%06ld", ppid);
+      snprintf(cppid, sizeof(cppid), "%06ld", (long)ppid);
       tmpname_timestamper =
          estrjoin("", "/tmp/feh_", cppid, "_", basename, NULL);
    }
@@ -545,12 +544,12 @@ feh_http_load_image(char *url)
          if (opt.wget_timestamp)
          {
             execlp("wget", "wget", "-N", "-O", tmpname_timestamper, newurl,
-                   quiet, NULL);
+                   quiet, (char*) NULL);
          }
          else
          {
             execlp("wget", "wget", "--cache", "0", newurl, "-O", tmpname,
-                   quiet, NULL);
+                   quiet, (char*) NULL);
          }
          eprintf("url: exec failed: wget:");
       }
@@ -760,7 +759,6 @@ feh_draw_caption(winwidget w)
    int x, y;
    Imlib_Image im = NULL;
    static DATA8 atab[256];
-   struct stat st;
    char *p;
    gib_list *lines, *l;
    static gib_style *caption_style = NULL;
@@ -932,20 +930,26 @@ feh_display_status(char stat)
 }
 
 void feh_edit_inplace_orient(winwidget w, int orientation) {
-  int orient, ret;
-  Imlib_Image old, new;
+  int ret;
+  Imlib_Image old;
   D_ENTER(4);
   if(!w->file
     || !w->file->data 
     || !FEH_FILE(w->file->data)->filename)
     D_RETURN_(4);
 
+  if (!strcmp(gib_imlib_image_format(w->im), "jpeg")) {
+    feh_edit_inplace_lossless_rotate(w, orientation);
+    feh_reload_image(w, 1, 1);
+    D_RETURN_(4);
+  }
+
   ret = feh_load_image(&old, FEH_FILE(w->file->data));
   if(ret) {
     gib_imlib_image_orientate(old, orientation);
     gib_imlib_save_image(old, FEH_FILE(w->file->data)->filename);
     gib_imlib_free_image(old);
-    feh_reload_image(w, 1);
+    feh_reload_image(w, 1, 1);
   } else {
     weprintf("failed to load image from disk to edit it in place\n");
   }
@@ -1056,3 +1060,119 @@ feh_wrap_string(char *text, int wrap_width, int max_height, Imlib_Font fn, gib_s
    }
    return lines;
 }
+
+void feh_edit_inplace_lossless_rotate(winwidget w, int orientation) {
+  FILE *input_file;
+  FILE *output_file;
+  struct jpeg_decompress_struct srcinfo;
+  struct jpeg_compress_struct dstinfo;
+  struct jpeg_error_mgr jsrcerr, jdsterr;
+  jvirt_barray_ptr * src_coef_arrays;
+  jvirt_barray_ptr * dst_coef_arrays;
+  JCOPY_OPTION copyoption;
+  jpeg_transform_info transformoption;
+  int len;
+  char *outfilename;
+  char *infilename = FEH_FILE(w->file->data)->filename;
+
+  copyoption = JCOPYOPT_ALL;
+  transformoption.transform = JXFORM_NONE;
+  transformoption.trim = FALSE;
+  transformoption.force_grayscale = FALSE;
+
+  if (orientation == 1) {
+    transformoption.transform = JXFORM_ROT_90;
+  } else if (orientation == 2) {
+    transformoption.transform = JXFORM_ROT_180;
+  } else {
+    transformoption.transform = JXFORM_ROT_270;
+  }
+  
+  if ((input_file = fopen(infilename, "rb")) == NULL) {
+    weprintf("couldn't open file for reading: %s\n", infilename);
+    D_RETURN_(4);
+  }
+  len = strlen(infilename) + sizeof(".tmp") + 1;
+  outfilename = emalloc(len);
+  snprintf(outfilename, len, "%s.tmp", infilename);
+
+  if ((output_file = fopen(outfilename, "wb")) == NULL) {
+    weprintf("couldn't open file for writing: %s\n", outfilename);
+    free(outfilename);
+    fclose(input_file);
+    D_RETURN_(4);
+  }
+
+  /* Initialize the JPEG decompression object with default error handling. */
+  srcinfo.err = jpeg_std_error(&jsrcerr);
+  jpeg_create_decompress(&srcinfo);
+
+  /* Initialize the JPEG compression object with default error handling. */
+  dstinfo.err = jpeg_std_error(&jdsterr);
+  jpeg_create_compress(&dstinfo);
+  jsrcerr.trace_level = jdsterr.trace_level;
+
+  /* Specify data source for decompression */
+  jpeg_stdio_src(&srcinfo, input_file);
+
+  /* Enable saving of extra markers that we want to copy */
+  jcopy_markers_setup(&srcinfo, copyoption);
+
+  /* Read file header */
+  (void) jpeg_read_header(&srcinfo, TRUE);
+
+  /* Any space needed by a transform option must be requested before
+   * jpeg_read_coefficients so that memory allocation will be done right.
+   */
+  jtransform_request_workspace(&srcinfo, &transformoption);
+
+  /* Read source file as DCT coefficients */
+  src_coef_arrays = jpeg_read_coefficients(&srcinfo);
+
+  /* Initialize destination compression parameters from source values */
+  jpeg_copy_critical_parameters(&srcinfo, &dstinfo);
+
+  /* Adjust destination parameters if required by transform options;
+   * also find out which set of coefficient arrays will hold the output.
+   */
+  dst_coef_arrays = jtransform_adjust_parameters(&srcinfo, &dstinfo,
+             src_coef_arrays,
+             &transformoption);
+
+  /* Specify data destination for compression */
+  jpeg_stdio_dest(&dstinfo, output_file);
+
+  /* Start compressor (note no image data is actually written here) */
+  jpeg_write_coefficients(&dstinfo, dst_coef_arrays);
+
+  /* Copy to the output file any extra markers that we want to preserve */
+  jcopy_markers_execute(&srcinfo, &dstinfo, copyoption);
+
+  /* Execute image transformation */
+  jtransform_execute_transformation(&srcinfo, &dstinfo,
+            src_coef_arrays,
+            &transformoption);
+
+  /* Finish compression and release memory */
+  jpeg_finish_compress(&dstinfo);
+  jpeg_destroy_compress(&dstinfo);
+
+  (void) jpeg_finish_decompress(&srcinfo);
+  jpeg_destroy_decompress(&srcinfo);
+
+  fclose(input_file);
+  fclose(output_file);
+
+  /* TODO fix EXIF tags (orientation, width, height) */
+
+  /* rename outfilename to infilename.. if it worked */
+  if (jsrcerr.num_warnings > 0) {
+    weprintf("got errors from libjpeg (%d), not replacing file\n", jsrcerr.num_warnings);
+  } else {
+    if (rename(outfilename, infilename)) {
+      weprintf("failed to replace file %s with %s\n", infilename, outfilename);
+    }
+  }
+  free(outfilename);
+}
+
