@@ -57,17 +57,19 @@ init_index_mode(void)
    int thumbnailcount = 0;
    gib_list *l = NULL, *last = NULL;
    feh_file *file = NULL;
-   int file_num = 0, lines;
+   int lines;
    unsigned char trans_bg = 0;
    int index_image_width, index_image_height;
    int x_offset_name = 0, x_offset_dim = 0, x_offset_size = 0;
    char *s;
 
-   file_num = gib_list_length(filelist);
-
    D_ENTER(3);
 
-   mode = "index";
+   if (opt.montage) {
+     mode = "montage";
+   } else {
+     mode = "index";
+   }
 
    fn = gib_imlib_load_font(opt.font);
 
@@ -200,7 +202,7 @@ init_index_mode(void)
                   "enough to hold all the thumnails you specified (%d). To fit all\n"
                   "the thumnails, either decrease their size, choose a smaller font,\n"
                   "or use a larger image (may I recommend %d by %d?)",
-                  opt.limit_w, opt.limit_h, file_num, opt.limit_w, rec_h);
+                  opt.limit_w, opt.limit_h, filelist_len, opt.limit_w, rec_h);
       }
    }
    else if (opt.limit_h)
@@ -346,6 +348,7 @@ init_index_mode(void)
       if (last)
       {
          filelist = feh_file_remove_from_list(filelist, last);
+         filelist_len--;
          last = NULL;
       }
       D(4, ("About to load image %s\n", file->filename));
