@@ -52,8 +52,8 @@ init_list_mode(void)
                 file->info->width, file->info->height, file->info->pixels,
                 file->info->size, file->info->has_alpha ? 'X' : '-',
                 file->filename);
-      if (opt.action)
-         feh_action_run(file);
+
+      feh_action_run(file,opt.actions[0]);
    }
    exit(0);
 }
@@ -98,8 +98,7 @@ real_loadables_mode(int loadable)
          if (loadable)
          {
             fprintf(stdout, "%s\n", file->filename);
-            if (opt.action)
-               feh_action_run(file);
+            feh_action_run(file,opt.actions[0]);
          }
          gib_imlib_free_image_and_decache(im);
       }
@@ -109,8 +108,7 @@ real_loadables_mode(int loadable)
          if (!loadable)
          {
             fprintf(stdout, "%s\n", file->filename);
-            if (opt.action)
-               feh_action_run(file);
+            feh_action_run(file,opt.actions[0]);
          }
       }
    }
