@@ -349,6 +349,8 @@ feh_parse_option_array(int argc, char **argv)
       {"scale-down", 0, 0, '.'},            /* okay */
       {"no-rotate-ctrl-mask", 0, 0, '7'},
       {"no-blur-ctrl-mask", 0, 0, '9'},
+      {"no-jump-on-resort",0,0,220},
+      {"hide-pointer",0,0,221},
       /* options with values */
       {"output", 1, 0, 'o'},                /* okay */
       {"output-only", 1, 0, 'O'},           /* okay */
@@ -402,7 +404,6 @@ feh_parse_option_array(int argc, char **argv)
       {"action7", 1, 0, 216},
       {"action8", 1, 0, 217},
       {"action9", 1, 0, 218},
-      {"no-jump-on-resort",0,0,220},
       {0, 0, 0, 0}
    };
    int optch = 0, cmdx = 0, i = 0;
@@ -715,6 +716,9 @@ feh_parse_option_array(int argc, char **argv)
         case 220:
            opt.no_jump_on_resort = 1;
            break;
+        case 221:
+           opt.hide_pointer = 1;
+           break;
         default:
            break;
       }
@@ -997,6 +1001,7 @@ show_usage(void)
 "                           size.  WARNING: with this option disabled,\n"
 "                           image windows could become very large, making\n"
 "                           them unmanageable in certain window managers.\n"
+"     --hide-pointer        In full screen mode, hide the X mouse pointer.\n"
 " FORMAT SPECIFIERS\n"
 "                           %%f image path/filename\n"
 "                           %%n image name\n"
@@ -1149,8 +1154,11 @@ feh_create_default_config(char *rcfile)
            "mkindex -iVO index.jpg .\n" "\n" "# More ambitious version...\n"
            "imgidx -iVO .fehindex.jpg --limit-width 1200 --thumb-width 90 --thumb-height 90 .\n"
            "\n" "# Show a presentation\n"
-           "present --full-screen --sort name\n" "\n" "# Booth mode ;-)\n"
-           "booth --full-screen --slideshow-delay 20\n" "\n"
+           "present --full-screen --sort name\n"
+           "\n"
+           "# Booth mode ;-)\n"
+           "booth --full-screen --hide-pointer --slideshow-delay 20\n"
+           "\n"
            "# Screw xscreensaver, use feh =)\n"
            "screensave --full-screen --randomize --slideshow-delay 5\n" "\n"
            "# Add <img> tags to your html with ease :-)\n"
