@@ -907,10 +907,10 @@ feh_thumbnail_generate(Imlib_Image *image, feh_file *file, char *thumb_file, cha
 
 		if (!stat(file->filename, &sb))
 		{
-			asprintf(&c_mtime, "%d", sb.st_mtime);
+      char c_mtime[256];
+			sprintf(c_mtime, "%d", sb.st_mtime);
 			feh_png_write_png(*image, thumb_file,
 												"Thumb::URI", uri, "Thumb::MTime", c_mtime);
-			free(c_mtime);
 		}
 
 		gib_imlib_free_image_and_decache(im_temp);
