@@ -32,6 +32,7 @@ static void winwidget_unregister(winwidget win);
 static void winwidget_register(winwidget win);
 static winwidget winwidget_allocate(void);
 
+static char bm_no_data[] = { 0,0,0,0, 0,0,0,0 };
 int window_num = 0;             /* For window list */
 winwidget *windows = NULL;      /* List of windows to loop though */
 
@@ -274,6 +275,16 @@ winwidget_create_window(winwidget ret,
     XSetWMNormalHints(disp, ret->win, &xsz);
     XMoveWindow(disp, ret->win, x, y);
   }
+  if (ret->full_screen && opt.hide_pointer) {
+    Cursor no_ptr;
+    XColor black, dummy;
+    Pixmap bm_no;
+    bm_no = XCreateBitmapFromData(disp, ret->win, bm_no_data, 8, 8);
+    XAllocNamedColor(disp, DefaultColormapOfScreen(DefaultScreenOfDisplay(disp)), "black", &black, &dummy);
+    
+    no_ptr = XCreatePixmapCursor(disp, bm_no, bm_no, &black, &black, 0, 0);
+    XDefineCursor(disp, ret->win, no_ptr);
+  }
 
   /* set the icon name property */
   XSetIconName(disp, ret->win, "feh");
